@@ -4,7 +4,7 @@
 #  (C) Paul Evans, 2019-2025 -- leonerd@leonerd.org.uk
 
 package Future::IO;
-our $VERSION = '0.17_001';
+our $VERSION = '0.17_002';
 
 use v5.14;
 use warnings;
@@ -612,14 +612,14 @@ sub load_best_impl
 
    # First, load a wrapper impl if the wrapped system is already loaded
    foreach ( @IMPLS_WRAPPER ) {
-      my ( $impl, $base ) = ref ? @$_ : ( $_, $_ );
+      my ( $impl, $base ) = ref $_ ? @$_ : ( $_, $_ );
       do { no strict 'refs'; %{"${base}::"} } or next;
 
       Future::IO->try_load_impl( $impl ) and return 1;
    }
 
    # OK, maybe we can find a good impl for this particular OS
-   foreach my $impl ( ( $IMPLS_FOR_OS{$^O} || [] )->@* ) {
+   foreach my $impl ( @{ $IMPLS_FOR_OS{$^O} || [] } ) {
       Future::IO->try_load_impl( $impl ) and return 1;
    }
 
